/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __FRAME_BROKER_TYPES_H__
#define __FRAME_BROKER_TYPES_H__

#include <tizen.h>
#include <app_control.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief Enumeration for frame broker error.
 * @since_tizen 5.5
 */
typedef enum {
	FRAME_BROKER_ERROR_NONE = TIZEN_ERROR_NONE,                             /**< Successful */
	FRAME_BROKER_ERROR_INVALID_PARAMETER = TIZEN_ERROR_INVALID_PARAMETER,   /**< Invalid parameter */
	FRAME_BROKER_ERROR_OUT_OF_MEMORY = TIZEN_ERROR_OUT_OF_MEMORY,           /**< Out of memory */
	FRAME_BROKER_ERROR_APP_NOT_FOUND = APP_CONTROL_ERROR_APP_NOT_FOUND,     /**< The application is not found */
	FRAME_BROKER_ERROR_LAUNCH_REJECTED = APP_CONTROL_ERROR_LAUNCH_REJECTED, /**< Launch rejected */
	FRAME_BROKER_ERROR_IO_ERROR = TIZEN_ERROR_IO_ERROR,                     /**< I/O error */
	FRAME_BROKER_ERROR_PERMISSION_DENIED = TIZEN_ERROR_PERMISSION_DENIED,   /**< Permission denied */
} frame_broker_error_e;

#ifdef __cplusplus
}
#endif

#endif /* __FRAME_BROKER_TYPES_H__ */
