/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __FRAME_CONTEXT_INTERNAL_H__
#define __FRAME_CONTEXT_INTERNAL_H__

#include <stdint.h>

#include "frame_broker.h"
#include "frame_context.h"

typedef enum {
	FRAME_CONTEXT_STATE_NONE,
	FRAME_CONTEXT_STATE_CREATED,
	FRAME_CONTEXT_STATE_RESUMED,
	FRAME_CONTEXT_STATE_PAUSED,
	FRAME_CONTEXT_STATE_DESTROYED,
} frame_context_state_e;

int frame_context_create(frame_broker_h broker,
		const char *app_id,
		const char *inst_id,
		int pid,
		uint32_t serial,
		frame_context_lifecycle_callback_s *callback,
		void *user_data,
		frame_context_h *handle);

int frame_context_destroy(frame_context_h handle);

int frame_context_get_pid(frame_context_h handle, int *pid);

int frame_context_set_serial(frame_context_h handle, uint32_t serial);

int frame_context_get_serial(frame_context_h handle, uint32_t *serial);

int frame_context_set_frame(frame_context_h handle, frame_h frame);

int frame_context_get_frame(frame_context_h handle, frame_h *frame);

int frame_context_set_state(frame_context_h handle,
		frame_context_state_e state);

int frame_context_get_state(frame_context_h handle,
		frame_context_state_e *state);

void frame_context_on_create(frame_context_h handle);

void frame_context_on_resume(frame_context_h handle, frame_h frame);

void frame_context_on_pause(frame_context_h handle);

void frame_context_on_destroy(frame_context_h handle);

void frame_context_on_error(frame_context_h handle,
		frame_context_error_e error);

#endif /* __FRAME_CONTEXT_INTERNAL_H__ */
