%bcond_with wayland

Name: libwidget_viewer
Summary: Library for developing the application
Version: 1.6.1
Release: 1
Group: Applications/Core Applications
License: Flora-1.1 and Apache-2.0
Source0: %{name}-%{version}.tar.gz
Source1001: %{name}_evas.manifest
Source1003: org.tizen.widget_viewer_sdk.manifest
Source1004: watch-control.manifest
Source1005: frame-broker.manifest
Source1006: frame-provider.manifest
BuildRequires: cmake, gettext-tools, coreutils, edje-bin
BuildRequires: pkgconfig(dlog)
BuildRequires: pkgconfig(aul)
BuildRequires: pkgconfig(glib-2.0)
BuildRequires: pkgconfig(gio-2.0)
BuildRequires: pkgconfig(sqlite3)
BuildRequires: pkgconfig(db-util)
BuildRequires: pkgconfig(widget_service)
BuildRequires: pkgconfig(vconf)
BuildRequires: pkgconfig(elementary)
BuildRequires: pkgconfig(pkgmgr-info)
BuildRequires: pkgconfig(capi-appfw-application)
BuildRequires: pkgconfig(appcore-efl)
BuildRequires: pkgconfig(capi-system-info)
BuildRequires: pkgconfig(efl-extension)
BuildRequires: pkgconfig(wayland-client)
BuildRequires: pkgconfig(libtbm)
BuildRequires: pkgconfig(libtzplatform-config)
BuildRequires: pkgconfig(cynara-client)
BuildRequires: pkgconfig(appsvc)
BuildRequires: pkgconfig(ecore-wl2)
BuildRequires: pkgconfig(wayland-tbm-client)
BuildRequires: pkgconfig(screen_connector_watcher_evas)
BuildRequires: pkgconfig(capi-system-device)
BuildRequires: pkgconfig(gmock)
BuildRequires: pkgconfig(screen_connector_launcher_service)
BuildRequires: pkgconfig(screen_connector_shared_widget_launch)
%if 0%{?gcov:1}
BuildRequires:  lcov
BuildRequires:  zip
%endif

%description
API for creating a new instance of the widget and managing its life-cycle.

%prep
%setup -q
cp %{SOURCE1001} .
cp %{SOURCE1003} .
cp %{SOURCE1004} .
cp %{SOURCE1005} .
cp %{SOURCE1006} .

%build
%if 0%{?gcov:1}
export CFLAGS+=" -fprofile-arcs -ftest-coverage"
export CXXFLAGS+=" -fprofile-arcs -ftest-coverage"
export FFLAGS+=" -fprofile-arcs -ftest-coverage"
export LDFLAGS+=" -lgcov"
%endif

export CFLAGS+=" -DEFL_BETA_API_SUPPORT "
MAJORVER=`echo %{version} | awk 'BEGIN {FS="."}{print $1}'`
%cmake -DWIDGET_ENABLED=On \
	-DTZ_SYS_SHARE=/usr/share \
	-DFULLVER=%{version} \
	-DMAJORVER=${MAJORVER} \
	.
make %{?jobs:-j%jobs}

%if 0%{?gcov:1}
mkdir -p gcov-obj
find . -name '*.gcno' -exec cp '{}' gcov-obj ';'
%endif

%check
ctest -V
%if 0%{?gcov:1}
lcov -c --ignore-errors graph --no-external -q -d . -o widget-viewer.info
genhtml widget-viewer.info -o widget-viewer.out
zip -r widget-viewer.zip widget-viewer.out
install -m 0644 widget-viewer.zip %{buildroot}%{_datadir}/gcov/
%endif

%install
rm -rf %{buildroot}
%make_install

%if 0%{?gcov:1}
mkdir -p %{buildroot}%{_datadir}/gcov/obj
install -m 0644 gcov-obj/* %{buildroot}%{_datadir}/gcov/obj
%endif

%post -n %{name} -p /sbin/ldconfig
%postun -n %{name} -p /sbin/ldconfig

#################################################
# libwidget_viewer_evas
%package -n %{name}_evas
Summary: Library for developing the widget viewer evas
Group: Applications/Core Applications
License: Flora-1.1

%description -n %{name}_evas
Provider APIs to develop the widget viewer EFL application.

%package -n %{name}_evas-devel
Summary: Widget provider application development library (dev) (EFL version)
Group: Development/Libraries
Requires: %{name}_evas

%description -n %{name}_evas-devel
Header & package configuration files to support development of the widget viewer applications. (for EFL app)

%post -n %{name}_evas -p /sbin/ldconfig
%postun -n %{name}_evas -p /sbin/ldconfig

#################################################
# org.tizen.widget_viewer_sdk
%package -n org.tizen.widget_viewer_sdk
Summary: The widget viewer for development using SDK(IDE)
Version: 0.0.1
Group: Development/Tools
License: Flora-1.1
Requires: %{name}_evas

%description -n org.tizen.widget_viewer_sdk
While developing the widget applications, this viewer will load it and execute it to help you to see it on the screen.

%post -n org.tizen.widget_viewer_sdk -p /sbin/ldconfig
%postun -n org.tizen.widget_viewer_sdk -p /sbin/ldconfig

#################################################
# widget-viewer_unittests
#################################################
%package -n widget-viewer_unittests
Summary:    GTest for widget-viewer
Group:      Development/Libraries

%description -n widget-viewer_unittests
GTest for widget-viewer

%files -n widget-viewer_unittests
%{_bindir}/widget-viewer_unittests

#################################################
# widget-viewer-gcov
#################################################
%if 0%{?gcov:1}
%package gcov
Summary:    Simple string key-val dictionary ADT (gcov)
Group:      Application Framework/Testing

%description gcov
Simple string key-val dictionary ADT gcov objects
%endif

%if 0%{?gcov:1}
%files gcov
%{_datadir}/gcov/*
%endif

################################################
# libwatch_control
%package -n watch-control
Summary: APIs to control watch applications
Version: 0.0.1
License: Flora-1.1
Group: Applications/Core Applications

%description -n watch-control
A set of APIs to control watch applications

%package -n watch-control-devel
Summary: APIs to control watch applications
Group: Development/Libraries
Requires: watch-control

%description -n watch-control-devel
Header & package configuration of watch-control

%post -n watch-control -p /sbin/ldconfig
%postun -n watch-control -p /sbin/ldconfig

################################################
# libframe-broker
################################################
%package -n frame-broker
Summary: APIs to handle launching images for the launcher
Version: 0.0.1
License: Apache-2.0
Group: Applications/Core Applications

%description -n frame-broker
A set of APIs to handle launching images for the launcher

%package -n frame-broker-devel
Summary: APIs to handle launching images for the launcher
Group: Development/Libraries
Requires: frame-broker

%description -n frame-broker-devel
Header & package configuration of launcher service

%post -n frame-broker -p /sbin/ldconfig
%postun -n frame-broker -p /sbin/ldconfig

################################################
# libframe-provider
################################################
%package -n frame-provider
Summary: APIs to handle launching images for the callee
Version: 0.0.1
License: Apache-2.0
Group: Applications/Core Applications

%description -n frame-provider
A set of APIs to handle launching images for the callee

%package -n frame-provider-devel
Summary: APIs to handle launching images for the callee (devel)
Group: Development/Libraries
Requires: frame-provider

%description -n frame-provider-devel
Header & package configuration for the callee (devel)

%post -n frame-provider -p /sbin/ldconfig
%postun -n frame-provider -p /sbin/ldconfig

################################################
# files
################################################
%files -n %{name}_evas
%manifest %{name}_evas.manifest
%attr(0644,root,root) %{_libdir}/%{name}_evas.so.*
%license LICENSE.Flora-1.1 LICENSE.Apache-2.0
/usr/share/widget_viewer_evas/res/edje/widget_viewer_evas.edj
/usr/share/widget_viewer_evas/res/image/*.png
/usr/share/widget_viewer_evas/res/locale/*/LC_MESSAGES/*
%{_bindir}/widget-mgr

%files -n %{name}_evas-devel
%{_includedir}/widget_viewer_evas/widget_viewer_evas.h
%{_includedir}/widget_viewer_evas/widget_viewer_evas_extension.h
%{_libdir}/pkgconfig/widget_viewer_evas.pc
%attr(0644,root,root) %{_libdir}/%{name}_evas.so

%files -n org.tizen.widget_viewer_sdk
%manifest org.tizen.widget_viewer_sdk.manifest
%{_datarootdir}/packages/org.tizen.widget_viewer_sdk.xml
%license LICENSE.Flora-1.1 LICENSE.Apache-2.0
%{_prefix}/apps/org.tizen.widget_viewer_sdk/*

%files -n watch-control
%manifest watch-control.manifest
%license LICENSE.Flora-1.1 LICENSE.Apache-2.0
%{_libdir}/libwatch-control.so.*

%files -n watch-control-devel
%{_includedir}/watch-control/*.h
%{_libdir}/pkgconfig/watch-control.pc
%{_libdir}/libwatch-control.so

%files -n frame-broker
%manifest frame-broker.manifest
%{_libdir}/libframe-broker.so.*

%files -n frame-broker-devel
%{_includedir}/frame-broker/*.h
%{_libdir}/pkgconfig/frame-broker.pc
%{_libdir}/libframe-broker.so

%files -n frame-provider
%manifest frame-provider.manifest
%{_libdir}/libframe-provider.so.*

%files -n frame-provider-devel
%{_includedir}/frame-provider/*.h
%{_libdir}/pkgconfig/frame-provider.pc
%{_libdir}/libframe-provider.so

# End of a file
