/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef MOCK_EVAS_H_
#define MOCK_EVAS_H_

#include <Evas.h>
#include "mock.h"

#ifdef __cplusplus
extern "C" {
#endif

#define ELM_WIN_UNKNOWN              0
#define ELM_WIN_BASIC                1
#define ELM_WIN_DIALOG_BASIC         2
#define ELM_WIN_DESKTOP              3
#define ELM_WIN_DOCK                 4
#define ELM_WIN_TOOLBAR              5
#define ELM_WIN_MENU                 6
#define ELM_WIN_UTILITY              7
#define ELM_WIN_SPLASH               8
#define ELM_WIN_DROPDOWN_MENU        9
#define ELM_WIN_POPUP_MENU           10
#define ELM_WIN_TOOLTIP              11
#define ELM_WIN_NOTIFICATION         12
#define ELM_WIN_COMBO                13

typedef int         Elm_Win_Type;

typedef void (*Efl_Signal_Cb) (void *data, Evas_Object *obj, const char *emission, const char *source); /**< Edje signal callback functions's prototype definition. @c data will have the auxiliary data pointer set at the time the callback registration. @c obj will be a pointer the Edje object where the signal comes from. @c emission will identify the exact signal's emission string and @c source the exact signal's source one. */
typedef Efl_Signal_Cb Edje_Signal_Cb;

DECLARE_FAKE_VALUE_FUNC(Evas_Object *, elm_win_add, Evas_Object *,
		const char *, Elm_Win_Type);

DECLARE_FAKE_VALUE_FUNC(Evas_Object *, elm_layout_add, Evas_Object *);

DECLARE_FAKE_VALUE_FUNC(Eina_Bool, elm_layout_file_set, Eo *, const char *,
		const char *);

DECLARE_FAKE_VALUE_FUNC(void *, evas_object_data_get, const Evas_Object *,
		const char *);

DECLARE_FAKE_VOID_FUNC(evas_object_data_set, Evas_Object *, const char *,
		const void *);

DECLARE_FAKE_VOID_FUNC(evas_object_event_callback_add, Evas_Object *,
		Evas_Callback_Type, Evas_Object_Event_Cb, const void *);

DECLARE_FAKE_VOID_FUNC(elm_object_signal_callback_add, Evas_Object *,
		const char *, const char *, Edje_Signal_Cb, void *);

DECLARE_FAKE_VOID_FUNC(elm_object_part_content_set, Evas_Object *, const char *,
		Evas_Object *);

DECLARE_FAKE_VALUE_FUNC(Evas_Object *, elm_object_part_content_get,
		const Evas_Object *, const char *);

DECLARE_FAKE_VOID_FUNC(elm_object_signal_emit, Evas_Object *, const char  *,
                const char  *);

#ifdef __cplusplus
}
#endif
#endif  /* MOCK_EVAS_H_ */
