// Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
// Use of this source code is governed by a apache 2.0 license that can be
// found in the LICENSE file.

#include "app_common.h"
#include "mock.h"
#include "gio/gio.h"
#include "system_info_mock.h"
#include "cynara_mock.h"
#include "evas_mock.h"
#include "aul_mock.h"
#include "widget_service_mock.h"
#include "screen_connector_mock.h"

DEFINE_FFF_GLOBALS;

DEFINE_FAKE_VALUE_FUNC(int, app_get_name, char**);

/* system */
DEFINE_FAKE_VALUE_FUNC(int, system_info_get_platform_bool,
    const char*, bool*);

/* cynara */
DEFINE_FAKE_VALUE_FUNC(int, cynara_initialize, cynara**,
    const cynara_configuration*);
DEFINE_FAKE_VALUE_FUNC(int, cynara_finish, cynara*);
DEFINE_FAKE_VALUE_FUNC(int, cynara_check, cynara*,
    const char*, const char*, const char*, const char*);
DEFINE_FAKE_VALUE_FUNC(int, cynara_creds_gdbus_get_client, GDBusConnection*,
    const gchar*, enum cynara_client_creds, gchar**);
DEFINE_FAKE_VALUE_FUNC(int, cynara_creds_gdbus_get_user, GDBusConnection*,
    const gchar*, enum cynara_user_creds, gchar**);

/* evas */
DEFINE_FAKE_VALUE_FUNC(Evas_Object *, elm_win_add, Evas_Object *,
		const char *, Elm_Win_Type);
DEFINE_FAKE_VALUE_FUNC(Evas_Object *, elm_layout_add, Evas_Object *);
DEFINE_FAKE_VALUE_FUNC(Eina_Bool, elm_layout_file_set, Eo *, const char *,
		const char *);
DEFINE_FAKE_VOID_FUNC(evas_object_data_set, Evas_Object *, const char *,
		const void *);
DEFINE_FAKE_VALUE_FUNC(void *, evas_object_data_get, const Evas_Object *,
		const char *);
DEFINE_FAKE_VOID_FUNC(evas_object_event_callback_add, Evas_Object *,
		Evas_Callback_Type, Evas_Object_Event_Cb, const void *);
DEFINE_FAKE_VOID_FUNC(elm_object_signal_callback_add, Evas_Object *,
		const char *, const char *, Edje_Signal_Cb, void *);
DEFINE_FAKE_VOID_FUNC(elm_object_part_content_set, Evas_Object *, const char *,
		Evas_Object *);
DEFINE_FAKE_VALUE_FUNC(Evas_Object *, elm_object_part_content_get,
		const Evas_Object *, const char *);
DEFINE_FAKE_VOID_FUNC(elm_object_signal_emit, Evas_Object *, const char  *,
        const char  *);

/* aul */
DEFINE_FAKE_VALUE_FUNC(int, aul_app_get_appid_bypid, int, char *, int);
DEFINE_FAKE_VALUE_FUNC_VARARG(int, aul_widget_write_log, const char *, const char *, ...);

/* widget_service */
DEFINE_FAKE_VALUE_FUNC(int, widget_service_get_widget_max_count, const char *);
DEFINE_FAKE_VALUE_FUNC(int, widget_instance_create, const char *, char **);

/* screen_connector */
DEFINE_FAKE_VALUE_FUNC(int, screen_connector_toolkit_evas_init,
        Evas_Object *, screen_connector_screen_type_e);